Enumeration
QmiLocTimeSource
since: 1.22
Members
-
QMI_LOC_TIME_SOURCE_INVALID -
Invalid.
- Value:
0 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_NETWORK_TIME_TRANSFER -
Time is set by the 1X system.
- Value:
1 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_NETWORK_TIME_TAGGING -
Time is set by WCDMA/GSM time tagging.
- Value:
2 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_EXTERNAL_INPUT -
Time set by external injection.
- Value:
3 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_TOW_DECODE -
Time is set after decoding over-the-air GPS navigation data from one GPS satellite.
- Value:
4 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_TOW_CONFIRMED -
Time is set after decoding over-the-air GPS navigation data from multiple satellites.
- Value:
5 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_TOW_AND_WEEK_CONFIRMED -
Both time of the week and GPS week number are known.
- Value:
6 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_NAVIGATION_SOLUTION -
Time is set by the position engine after the fix is obtained.
- Value:
7 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_SOLVE_FOR_TIME -
Time is set by the position engine after performing SFT.
- Value:
8 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_GLO_TOW_DECODE -
Time is set after decoding QZSS satellites.
- Value:
9 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_TIME_TRANSFORM -
Time is set after transforming the GPS to GLO time.
- Value:
10 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_WCDMA_SLEEP_TIME_TAG -
Time is set by the sleep time tag provided by the WCDMA network.
- Value:
11 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_GSM_SLEEP_TIME_TAG -
Time is set by the sleep time tag provided by the GSM network.
- Value:
12 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_UNKNOWN -
Unknown.
- Value:
13 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_SYSTEM_TIMETICK -
Time is derived from the system clock.
- Value:
14 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_QZSS_TOW_DECODE -
Time set after decoding QZSS satellites.
- Value:
15 - Available since: 1.22
- Value:
-
QMI_LOC_TIME_SOURCE_BDS_TOW_DECODE -
Time set after decoding BDS satellites.
- Value:
16 - Available since: 1.22
- Value:
Type functions
qmi_loc_time_source_get_string
Gets the nickname string for the QmiLocTimeSource specified at val.
since: 1.22